import type { CliOptions, CommandError, Subprocess } from '@stacksjs/types';
import type { Result } from '@stacksjs/error-handling';
/**
 * Run a command.
 *
 * @param command The command to run.
 * @param options The options to pass to the command.
 * @returns The result of the command.
 * @example
 * ```ts
 * const result = await runCommand('ls')
 *
 * if (result.isErr())
 *   console.error(result.error)
 * else
 *   console.log(result)
 * ```
 * @example
 * ```ts
 * const result = await runCommand('ls', { cwd: '/home' })
 *
 * if (result.isErr())
 *   console.error(result.error)
 * else
 *   console.log(result)
 * ```
 */
export declare function runCommand(command: string, options?: CliOptions): Promise<Result<Subprocess, CommandError>>;
export declare function runProcess(command: string, options?: CliOptions): Promise<Result<Subprocess, CommandError>>;
/**
 * Run a command.
 *
 * @param command The command to run.
 * @param options The options to pass to the command.
 * @returns The result of the command.
 * @example
 * ```ts
 * const result = runCommandSync('ls')
 *
 * if (result.isErr())
 *   console.error(result.error)
 * else
 *   console.log(result)
 * ```
 * @example
 * ```ts
 * const result = runCommandSync('ls', { cwd: '/home' })
 *
 * if (result.isErr())
 *   console.error(result.error)
 * else
 *   console.log(result)
 * ```
 */
export declare function runCommandSync(command: string, options?: CliOptions): Promise<string>;
/**
 * Run many commands.
 *
 * @param commands The command to run.
 * @param options The options to pass to the command.
 * @returns The result of the command.
 */
export declare function runCommands(commands: string[], options?: CliOptions): Promise<(import("neverthrow").Ok<Subprocess, CommandError> | import("neverthrow").Err<Subprocess, CommandError>)[]>;
